var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import VueI18n from "vue-i18n";
export class VueI18x extends VueI18n {
    constructor() {
        super({
            fallbackLocale: "en",
            silentFallbackWarn: process.env.NODE_ENV === "production",
            silentTranslationWarn: process.env.NODE_ENV === "production"
        });
        this._fetchingLocales = new Map();
    }
    static install(Vue) {
        super.install(Vue);
        Vue.directive("x", {
            bind: directive,
            update: directive
        });
        Vue.mixin({
            computed: {
                $i18x() {
                    return this.$i18n;
                }
            }
        });
        Vue.prototype.$x = function (key, value, params) {
            if (process.env.NODE_ENV === "development") {
                if (typeof key !== "number") {
                    return key;
                }
            }
            return this.$t(this.$options.i18nPrefix + key, params);
        };
    }
    get locale() {
        return super.locale;
    }
    set locale(value) {
        if (process.env.NODE_ENV === "development") {
            console.warn("[vuechain] locale was changed without fetching messages beforehand.");
        }
        super.locale = value;
    }
    /** Fetch and set the locale. */
    changeLocale(locale) {
        const _super = Object.create(null, {
            locale: { get: () => super.locale, set: v => super.locale = v }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield this.prefetchLocale(locale);
            _super.locale = locale;
        });
    }
    /**
     * Autodetect, fetch and set the locale.
     * If no supported locale is detected, the first supported locale is used as the fallback.
     */
    changeLocaleAuto(supportedLocales) {
        const locales = new Set(supportedLocales);
        for (const lang of navigator.languages) {
            const langCode = /^[^\-_]+/.exec(lang);
            if (langCode && locales.has(langCode[0])) {
                return this.changeLocale(langCode[0]);
            }
        }
        return this.changeLocale(supportedLocales[0]);
    }
    prefetchLocale(locale) {
        let request = this._fetchingLocales.get(locale);
        if (!request) {
            request = this.fetchLocale(locale);
            this._fetchingLocales.set(locale, request);
        }
        return request;
    }
    fetchLocale(locale) {
        return __awaiter(this, void 0, void 0, function* () {
            const req = yield fetch(`${__webpack_public_path__}locale/${locale}.json`);
            if (req.status === 200 || req.status === 204) {
                const messages = yield req.json();
                this.mergeLocaleMessage(locale, messages);
            }
            else {
                throw new Error(`Unable to fetch locale: ${locale}. The server returned ${req.status}`);
            }
        });
    }
}
function directive(el, binding, vnode) {
    if (process.env.NODE_ENV === "development") {
        if (typeof binding.value !== "number" && (typeof binding.value[0] !== "number" || (binding.value[1] && typeof binding.value[1] !== "object"))) {
            console.warn("[vuechain] v-x directive must be a number, or an array with a number as the first element and an object as the second element.", binding.value, vnode);
        }
        if (vnode.context) {
            if (vnode.componentInstance) {
                if (!vnode.componentInstance.$slots || !vnode.componentInstance.$slots.default) {
                    console.warn("[vuechain] v-x directive was used on a component without a default slot.", vnode);
                }
            }
        }
        else {
            console.warn("[vuechain] v-x directive was used without context.", vnode);
        }
    }
    const context = vnode.context;
    if (context) {
        const prefix = context.$options.i18nPrefix;
        const text = typeof binding.value === "number"
            ? context.$t(prefix + binding.value)
            : context.$t(prefix + binding.value[0], binding.value[1]);
        if (el._i18xText !== text) {
            el._i18xText = text;
            let vm, slot, slotContent, slotElem;
            if (vm = vnode.componentInstance) {
                if ((slot = vm.$slots.default) && (slotContent = slot[0]) && (slotElem = slotContent.elm)) {
                    slotElem.textContent = text;
                }
            }
            else {
                el.innerText = text;
            }
        }
    }
}
//# sourceMappingURL=i18x.js.map