#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("v8-compile-cache");
const command_1 = require("@phylum/command");
const util_1 = require("util");
const config_1 = require("./config");
;
(async () => {
    const argv = process.argv.slice(2);
    const command = argv.shift();
    switch (command) {
        case "start":
        case "build":
            await (await Promise.resolve().then(() => require("./commands/build"))).run(command, argv);
            break;
        case "clean":
            await (await Promise.resolve().then(() => require("./commands/clean"))).run(command, argv);
            break;
        case "init":
            await (await Promise.resolve().then(() => require("./commands/init"))).run(command, argv);
            break;
        default:
            process.exitCode = 1;
            console.error(`Unknown command: "${command}"`);
        case "help":
        case undefined:
            await (await Promise.resolve().then(() => require("./commands/help"))).run(command, argv);
            break;
    }
})().catch(error => {
    process.exitCode = 1;
    if (error instanceof command_1.CommandError) {
        error = error.message;
    }
    if (error instanceof config_1.ConfigError) {
        error = `Invalid configuration (${error.filename}):\n${error.message}`;
    }
    console.error(typeof error === "string" ? error : util_1.inspect(error));
});
//# sourceMappingURL=cli.js.map