"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const command_1 = require("@phylum/command");
exports.VC_PACKAGE_TYPES = new Set(["application", "library"]);
exports.VC_PACKAGE_TYPES_STR = Array.from(exports.VC_PACKAGE_TYPES).map(t => `"${t}"`).join(", ");
exports.VC_PACKAGE_TYPE_ARG = Object.assign((value, spec) => {
    if (!exports.VC_PACKAGE_TYPES.has(value)) {
        throw new command_1.CommandError(`Usage: ${command_1.formatUsage(spec)}`);
    }
    return value;
}, {
    displayName: exports.VC_PACKAGE_TYPES_STR
});
class ConfigError extends TypeError {
    constructor(filename, message) {
        super(message);
        this.filename = filename;
    }
}
exports.ConfigError = ConfigError;
async function loadConfig(context) {
    context = path_1.resolve(context);
    const filename = path_1.join(context, "vuechain.json");
    const config = await fs_extra_1.readJson(filename);
    config.context = context;
    config.filename = filename;
    config.external = /[\\\/]node_modules[\\\/]/.test(context);
    if (!exports.VC_PACKAGE_TYPES.has(config.packageType)) {
        throw new ConfigError(filename, `config.packageType must be one of ${exports.VC_PACKAGE_TYPES_STR}`);
    }
    config.rootDir = path_1.resolve(context, config.rootDir || "src");
    config.outDir = path_1.resolve(context, config.outDir || "dist");
    if (config.prefix !== undefined && typeof config.prefix !== "string") {
        throw new ConfigError(filename, `config.prefix must be undefined or a string.`);
    }
    if (config.adapter !== undefined && typeof config.adapter !== "string") {
        throw new ConfigError(filename, `config.adapter must be undefined or a string.`);
    }
    return config;
}
exports.loadConfig = loadConfig;
function tryLoadConfig(context) {
    return loadConfig(context).catch(error => {
        if (error && error.code === "ENOENT") {
            return undefined;
        }
        throw error;
    });
}
exports.tryLoadConfig = tryLoadConfig;
//# sourceMappingURL=config.js.map