"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_extra_1 = require("fs-extra");
class DefaultI18nAdapter {
    async process(ctx) {
        const dataFilename = path_1.join(ctx.config.context, "i18n.json");
        const data = await fs_extra_1.readJson(dataFilename).catch(error => {
            if (error && error.code === "ENOENT") {
                return {};
            }
            throw error;
        });
        const unprocessedFiles = new Set(Object.keys(data));
        for (const [filename, file] of ctx.files) {
            if (file.pairs.length > 0) {
                const relname = getRelname(file.meta.context, filename);
                unprocessedFiles.delete(relname);
                let fileData = data[relname];
                if (!fileData) {
                    fileData = data[relname] = { content: {} };
                }
                const unprocessedKeys = new Set(Object.keys(fileData.content));
                for (const { key, value } of file.pairs) {
                    unprocessedKeys.delete(key);
                    let entry = fileData.content[key];
                    if (entry) {
                        if (entry.content !== value) {
                            entry.content = value;
                            entry.lastModified = new Date().toISOString();
                        }
                        if (entry.content === value) {
                            ctx.bundleMessages("en", entry.content, key);
                            const latest = new Date(entry.lastModified).getTime();
                            for (const locale in entry.translations) {
                                if (new Date(entry.translations[locale].lastModified).getTime() >= latest) {
                                    ctx.bundleMessages(locale, entry.translations[locale].content, key);
                                }
                            }
                        }
                    }
                    else {
                        entry = fileData.content[key] = {
                            content: value,
                            lastModified: new Date().toISOString(),
                            ignoreSpelling: [],
                            translations: {}
                        };
                    }
                }
                for (const key of unprocessedKeys) {
                    delete fileData.content[key];
                }
            }
        }
        for (const relname of unprocessedFiles) {
            delete data[relname];
        }
        await fs_extra_1.writeFile(dataFilename, JSON.stringify(data, null, "\t"));
    }
}
exports.DefaultI18nAdapter = DefaultI18nAdapter;
function getRelname(context, filename) {
    return path_1.relative(context, filename).replace(/\\/g, "/");
}
//# sourceMappingURL=default-adapter.js.map