"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ignoredNodes = new Set(["#comment", "#documentType", "#text"]);
function* traverseNodes(node) {
    if (!ignoredNodes.has(node.nodeName)) {
        yield node;
        if (node.childNodes) {
            for (const childNode of node.childNodes) {
                yield* traverseNodes(childNode);
            }
        }
        if (node.content) {
            yield* traverseNodes(node.content);
        }
    }
}
exports.traverseNodes = traverseNodes;
function getAttr(node, name) {
    if (!node.attrs) {
        return;
    }
    for (const attr of node.attrs) {
        if (attr.name === name) {
            const location = node.sourceCodeLocation.attrs[name];
            return {
                start: location.startOffset,
                end: location.endOffset,
                value: attr.value
            };
        }
    }
    return;
}
exports.getAttr = getAttr;
function getTextContent(node) {
    let content = "";
    if (node.childNodes) {
        for (const childNode of node.childNodes) {
            if (childNode.nodeName === "#text") {
                content += childNode.value;
            }
        }
    }
    return content
        // Remove leading and trailing whitespace if it contains a new line:
        .replace(/(^\s*\n\s*)|(\s*\n\s*$)/g, "")
        // Collapse reimaining whitespace to single spaces:
        .replace(/\s\s+/g, " ");
}
exports.getTextContent = getTextContent;
//# sourceMappingURL=html.js.map