"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Justify i18x keys.
 * @param source The source code.
 * @param entities The parsed i18x entities.
 */
function justifySource(source, entities) {
    const entityKeys = [];
    const usedKeys = new Map();
    // Register existing keys that should not be changed:
    for (const entity of entities) {
        if (entity.key !== undefined && !usedKeys.has(entity.key)) {
            usedKeys.set(entity.key, entity);
        }
    }
    // Justify missing or duplicate keys:
    let nextKey = 0;
    for (const entity of entities) {
        if (entity.key === undefined || usedKeys.get(entity.key) !== entity) {
            while (usedKeys.has(nextKey)) {
                nextKey++;
            }
            usedKeys.set(nextKey, entity);
            entityKeys.push([entity, nextKey]);
        }
        else {
            entityKeys.push([entity, entity.key]);
        }
    }
    // Format the source code with the justified keys:
    let output = "";
    let pos = 0;
    for (const [entity, key] of entityKeys) {
        output += source.slice(pos, entity.start);
        switch (entity.type) {
            case "x":
                output += `${key}, `;
                break;
            case "directive":
                output += `v-x="${key}"`;
                break;
            case "extended-directive":
                output += `v-x="[${key}, ${entity.options}]"`;
                break;
        }
        pos = entity.end;
    }
    output += source.slice(pos);
    return {
        pairs: entityKeys.map(([entity, key]) => ({ key, value: entity.value })),
        output
    };
}
exports.justifySource = justifySource;
//# sourceMappingURL=justify-source.js.map