"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class I18nMergeError extends Error {
    constructor(path) {
        super(`Unable to merge i18n message at path: "${path.join(".")}"`);
    }
}
exports.I18nMergeError = I18nMergeError;
function parseMessagePath(path) {
    return path ? path.split(".") : [];
}
exports.parseMessagePath = parseMessagePath;
function mergeMessages(target, path, messages) {
    if (typeof messages === "string") {
        const last = path.pop();
        if (last) {
            messages = { [last]: messages };
        }
        else {
            throw new I18nMergeError([]);
        }
    }
    (function merge(target, messages, currentPath) {
        for (const key in messages) {
            if (typeof messages[key] === "string") {
                if (key in target) {
                    throw new I18nMergeError(currentPath.concat(key));
                }
                else {
                    target[key] = messages[key];
                }
            }
            else {
                if (typeof target[key] === "string") {
                    throw new I18nMergeError(currentPath.concat(key));
                }
                merge(target[key] || (target[key] = {}), messages[key], currentPath.concat(key));
            }
        }
    })(target = path.reduce((target, key, i) => {
        const next = target[key];
        if (typeof next === "string") {
            throw new I18nMergeError(path.slice(0, i));
        }
        return next ? next : (target[key] = {});
    }, target), messages, path);
}
exports.mergeMessages = mergeMessages;
function getLocaleMessageAssetPath(locale) {
    return `locale/${locale}.json`;
}
exports.getLocaleMessageAssetPath = getLocaleMessageAssetPath;
//# sourceMappingURL=messages.js.map