"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const querystring_1 = require("querystring");
const file_meta_1 = require("../../i18n/file-meta");
const common_1 = require("./common");
async function default_1(source, map, meta) {
    const callback = this.async();
    try {
        const query = querystring_1.parse(this.resourceQuery.slice(1));
        const type = path_1.extname(this.resourcePath);
        const meta = file_meta_1.getFileMeta(this.resourcePath);
        if (meta) {
            const plugin = this._compilation[common_1.I18N_PLUGIN_KEY];
            const config = await plugin.getPackageConfig(meta.context);
            if (config) {
                if (config.external) {
                    const manifest = await plugin.getPackageManifest(config);
                    if (manifest) {
                        const keys = manifest.keys.get(this.resourcePath);
                        if (keys) {
                            const dependency = plugin.getDependency(config);
                            for (const key of keys) {
                                dependency.keys.add(key);
                            }
                        }
                    }
                }
                else {
                    this.addDependency(config.filename);
                    const prefix = meta.getPrefix(config);
                    switch (type) {
                        case ".vue":
                            if (query.type === "script") {
                                source = injectScriptPrefix(source, prefix);
                            }
                            if (query.vue === undefined) {
                                source = injectVuePrefix(source, prefix);
                                this._module[common_1.I18N_MODULE_META_KEY] = meta;
                                this._module[common_1.I18N_MODULE_CONFIG_KEY] = config;
                            }
                            break;
                        default:
                            source = injectScriptPrefix(source, prefix);
                            this._module[common_1.I18N_MODULE_META_KEY] = meta;
                            this._module[common_1.I18N_MODULE_CONFIG_KEY] = config;
                            break;
                    }
                }
            }
        }
        callback(null, source, map, meta);
    }
    catch (error) {
        callback(error);
    }
}
exports.default = default_1;
function injectScriptPrefix(source, prefix) {
    return `const i18nPrefix = ${JSON.stringify(prefix)};${source}`;
}
function injectVuePrefix(source, prefix) {
    return `${source}\n; component.options.i18nPrefix = ${JSON.stringify(prefix)};`;
}
//# sourceMappingURL=i18n-loader.js.map