"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("../../../config");
const package_manifest_1 = require("../../../i18n/package-manifest");
const messages_1 = require("../../../i18n/messages");
class I18nContext {
    constructor(config, runner) {
        this.config = config;
        this.runner = runner;
        this._packageConfigRequests = new Map();
        this._packageManifestRequests = new Map();
        this._sourceOutputRelations = new Map();
        this.locales = new Map();
        this.files = new Map();
    }
    getPackageConfig(context) {
        let request = this._packageConfigRequests.get(context);
        if (!request) {
            this._packageConfigRequests.set(context, request = config_1.tryLoadConfig(context));
        }
        return request;
    }
    getPackageManifest(config) {
        let request = this._packageManifestRequests.get(config.context);
        if (!request) {
            this._packageManifestRequests.set(config.context, request = package_manifest_1.getPackageManifest(config));
        }
        return request;
    }
    /**
     * Add an output-source file relation.
     * @param distOutputFilename The output filename (relative to config.outDir)
     * @param sourceFilename The source filename.
     */
    setOutputSourceRelation(distOutputFilename, sourceFilename) {
        if (/\.js$/.test(sourceFilename) && !this.files.has(sourceFilename)) {
            sourceFilename = sourceFilename.replace(/\.js$/, ".ts");
        }
        distOutputFilename = distOutputFilename.replace(/\\/g, "/");
        if (this.files.has(sourceFilename)) {
            this._sourceOutputRelations.set(sourceFilename, distOutputFilename);
        }
    }
    /** Generate a manifest from the current context. */
    generateManifest() {
        const keys = [];
        for (const [filename, file] of this.files) {
            if (file.meta.context === this.config.context && this._sourceOutputRelations.get(filename) && file.pairs.length > 0) {
                keys.push({
                    filename: this._sourceOutputRelations.get(filename),
                    keys: file.pairs.map(pair => pair.key)
                });
            }
        }
        return {
            version: 1,
            keys,
            locales: Array.from(this.locales.keys())
        };
    }
    bundleMessages(locale, messages, path) {
        let target = this.locales.get(locale);
        if (!target) {
            this.locales.set(locale, target = {});
        }
        messages_1.mergeMessages(target, messages_1.parseMessagePath(path || ""), messages);
    }
}
exports.I18nContext = I18nContext;
//# sourceMappingURL=context.js.map