"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
const Vinyl = require("vinyl");
const vinyl_1 = require("./utility/vinyl");
const error_1 = require("./vue/error");
function createPostprocessor(options) {
    return new stream_1.Transform({
        objectMode: true,
        async transform(chunk, encoding, callback) {
            try {
                await postprocess.call(this, chunk, options.vueDecomposer);
                callback();
            }
            catch (error) {
                if (error instanceof error_1.VueError) {
                    options.error(error);
                    callback();
                }
                else {
                    callback(error);
                }
            }
        }
    });
}
exports.createPostprocessor = createPostprocessor;
async function postprocess(chunk, decomposer) {
    const vueStyleSuffix = /--s([0-9]+)\.css$/.exec(chunk.relative);
    if (vueStyleSuffix) {
        const relname = chunk.relative.slice(0, -vueStyleSuffix[0].length);
        const meta = decomposer.components.get(relname);
        if (meta) {
            const source = vinyl_1.getSource(chunk);
            const styleId = Number(vueStyleSuffix[1]);
            const vue = await Promise.resolve().then(() => require("@vue/component-compiler-utils"));
            const { code, errors } = vue.compileStyle({
                source,
                filename: chunk.path,
                id: meta.scopeId,
                scoped: meta.scopedStyles.has(styleId),
                trim: true
            });
            if (errors.length > 0) {
                throw new error_1.VueError(chunk.path.slice(0, -vueStyleSuffix[0].length) + ".vue", errors);
            }
            chunk.contents = Buffer.from(code);
        }
    }
    if (/\.scss$/.test(chunk.relative)) {
        this.push(new Vinyl({
            history: [...chunk.history],
            contents: Buffer.from(`import "./${chunk.stem}.css";`),
            cwd: chunk.cwd,
            base: chunk.base,
            path: `${chunk.path}.js`
        }));
        this.push(new Vinyl({
            history: [...chunk.history],
            contents: Buffer.from(""),
            cwd: chunk.cwd,
            base: chunk.base,
            path: `${chunk.path}.d.ts`
        }));
    }
    this.push(chunk);
}
exports.postprocess = postprocess;
// TODO: Split this file into specific postprocessors for vue and sass.
//# sourceMappingURL=postprocess.js.map