"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_1 = require("typescript");
const colors = require("ansi-colors");
// The following logging behavior is the same as in ts-loader (see npm) to
// provide a bit more consistency between different build systems (gulp and webpack).
const categories = new Map([
    [typescript_1.DiagnosticCategory.Error, { style: colors.redBright, label: "ERROR" }],
    [typescript_1.DiagnosticCategory.Message, { style: colors.green, label: "MESSAGE" }],
    [typescript_1.DiagnosticCategory.Warning, { style: colors.yellow, label: "WARNING" }]
]);
function formatTsError(error) {
    const category = categories.get(error.diagnostic.category);
    if (category) {
        return category.style(`[ts] ${category.label} in ${colors.cyanBright(`${error.fullFilename}${error.startPosition ? `(${formatPosition(error.startPosition)})` : ""}`)}\n     TS${error.diagnostic.code}: ${error.diagnostic.messageText}`);
    }
}
exports.formatTsError = formatTsError;
function formatPosition({ line, character }) {
    return `${line},${character}`;
}
//# sourceMappingURL=ts.js.map