/// <reference types="node" />
import { Transform } from "stream";
import { VueError } from "./error";
export interface VueDecomposeOptions {
    error(error: VueError): void;
}
export interface VueComponentMeta {
    readonly scopeId: string;
    readonly scopedStyles: Set<number>;
}
export interface VueDecomposer {
    readonly stream: Transform;
    readonly components: Map<string, VueComponentMeta>;
}
/**
 * Create a transform stream that consumes vue single component files
 * and decomposes them into their individual parts.
 *
 * Emitted file types can be ".ts", ".js", ".scss" and ".css".
 * Before writing the final files to disk, they should be piped through
 * a composeVue transform to apply some final transformations.
 */
export declare function createVueDecomposer(options: VueDecomposeOptions): VueDecomposer;
