"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Generate entry module code that imports decomposed parts of a
 * vue component and exports a normalized vue component as default.
 *
 * (Named exports from the component script are currently not supported, which
 * will pass through typescript silently, but break during the webpack build)
 */
exports.componentEntry = ({ stem, hasTemplate, hasScript, hasStyles, scoped, scopeId }) => `
import { compose } from "vuechain/runtime/compose";
${hasTemplate ? `import { render, staticRenderFns } from "./${stem}--r.js";\n` : ""}
${hasScript ? `import script from "./${stem}--s.js";\n` : ""}
${Array.from(new Array(hasStyles)).map((_, i) => `import "./${stem}--s${i}.css";\n`).join("")}

export default compose(
	/* render */ ${hasTemplate ? "render" : "null"},
	/* staticRenderFns */ ${hasTemplate ? "staticRenderFns" : "null"},
	/* script */ ${hasScript ? "script" : "null"},
	/* scopeId */ ${scoped ? JSON.stringify(scopeId) : null},
	/* i18nPrefix */ null
);
`;
exports.componentDeclaration = ({ stem, hasDeclaration }) => `
${hasDeclaration
    ? `export * from "./${stem}--s";`
    : `import Vue from "vue";\ndeclare const _default: import("vue").VueConstructor<Vue>;\nexport default _default;`}`;
/**
 * Generate template module code that exports compiled render functions.
 * The code must define two constants: `render` and `staticRenderFns`
 */
exports.templateModule = ({ code }) => `${code}
export { render, staticRenderFns };
`;
//# sourceMappingURL=generator.js.map